==> haskell-vault-0.3.1.5-296.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vault
version:              0.3.1.5
visibility:           public
id:                   vault-0.3.1.5-1WesiFbrgeBJ6Pz5D8LxKa
key:                  vault-0.3.1.5-1WesiFbrgeBJ6Pz5D8LxKa
license:              BSD-3-Clause
copyright:            (c) Heinrich Apfelmus 2011-2013
maintainer:           Heinrich Apfelmus <apfelmus at quantentunnel de>
author:               Heinrich Apfelmus, Elliott Hird
homepage:             https://github.com/HeinrichApfelmus/vault
synopsis:             a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.

    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.

    Also provided is a /locker/ type, representing a store for a single element.

category:             Data
abi:                  454ddad8b5b3d957d5dd1a67f1f88ed2
exposed:              True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vault-0.3.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vault-0.3.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vault-0.3.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vault
hs-libraries:         HSvault-0.3.1.5-1WesiFbrgeBJ6Pz5D8LxKa
depends:
    base-4.18.2.1 containers-0.6.7
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    unordered-containers-0.2.20.1-50qrTxmoJy9AxZ7OdMnycu

haddock-interfaces:   /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html:         /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-vault-0.3.1.5-297-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-vault.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 vault
version:              0.3.1.5
visibility:           public
id:                   vault-0.3.1.5-A9Ty7yzuPZlIa80zuSIl14
key:                  vault-0.3.1.5-A9Ty7yzuPZlIa80zuSIl14
license:              BSD-3-Clause
copyright:            (c) Heinrich Apfelmus 2011-2013
maintainer:           Heinrich Apfelmus <apfelmus at quantentunnel de>
author:               Heinrich Apfelmus, Elliott Hird
homepage:             https://github.com/HeinrichApfelmus/vault
synopsis:             a persistent store for values of arbitrary types
description:
    A /vault/ is a persistent store for values of arbitrary types.
    It'\''s like having first-class access to the storage space behind IORefs.

    The data structure is analogous to a bank vault,
    where you can access different bank boxes with different keys;
    hence the name.

    Also provided is a /locker/ type, representing a store for a single element.

category:             Data
abi:                  3fdef782aada6c87c8a82075928ffe8c
exposed:              True
exposed-modules:
    Data.Unique.Really Data.Vault.Lazy Data.Vault.ST.Lazy
    Data.Vault.ST.Strict Data.Vault.Strict

import-dirs:          /usr/lib/ghc-9.6.6/site-local/vault-0.3.1.5
library-dirs:         /usr/lib/ghc-9.6.6/site-local/vault-0.3.1.5
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/vault-0.3.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-vault
hs-libraries:         HSvault-0.3.1.5-A9Ty7yzuPZlIa80zuSIl14
depends:
    base-4.18.2.1 containers-0.6.7
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    unordered-containers-0.2.20.1-L0jiELAFLwP1g4FZscm3B5

haddock-interfaces:   /usr/share/doc/haskell-vault/html/vault.haddock
haddock-html:         /usr/share/doc/haskell-vault/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
